pub fn predict(args: &[ArgValue]) -> Result<String, FCError>Expand description
Linear extrapolation using the last two numeric values inside provided arguments. Non-numeric items cause a higher-level error, so this function assumes inputs are numeric.