pub fn all_command_names() -> Vec<&'static str>Expand description
Returns a list of all valid command names understood by the parser.
This is primarily intended for internal consistency checks (e.g., tests
that ensure spec::SPECS and the parser stay in sync).